oc\_ocdm.graph.entities.bibliographic.bibliographic\_reference module
---------------------------------------------------------------------

.. automodule:: oc_ocdm.graph.entities.bibliographic.bibliographic_reference
   :members:
   :undoc-members:
   :show-inheritance:
